@@ -19,6 +19,7 @@
 #' * IPUMS Time Use (`"atus"`, `"ahtus"`, `"mtus"`)
 #' * IPUMS Health Surveys (`"nhis"`, `"meps"`)
 #' * IPUMS NHGIS (`"nhgis"`)
+#' * IPUMS IHGIS (`"ihgis"`)
 #'
 #' Learn more about the IPUMS API in `vignette("ipums-api")`.
 #'
@@ -527,7 +528,7 @@ print.micro_extract <- function(x, ...) {
 }
 
 #' @export
-print.nhgis_extract <- function(x, ...) {
+print.agg_extract <- function(x, ...) {
   style_ds <- extract_field_styler(nhgis_print_color("dataset"), "bold")
 
   ds_to_cat <- purrr::map(
@@ -539,7 +540,8 @@ print.nhgis_extract <- function(x, ...) {
           "Tables: " = d$data_tables,
           "Geog Levels: " = d$geog_levels,
           "Years: " = d$years,
-          "Breakdowns: " = d$breakdown_values
+          "Breakdowns: " = d$breakdown_values,
+          "Tabulation Geogs: " = d$tabulation_geographies
         ),
         parent_style = style_ds,
         subfield_style = extract_field_styler("italic")
@@ -769,17 +771,17 @@ validate_api_request <- function(res, call = caller_env()) {
       # if any error details exist.
       if (length(error_details) > 0) {
         error_details <- c("x" = "Invalid IPUMS registration", error_details)
+      } else {
+        # Otherwise we should be dealing with a valid registration but invalid key
+        error_details <- c(
+          "x" = "The provided API key is either missing or invalid.",
+          "i" = paste0(
+            "Please provide your API key to the `api_key` argument ",
+            "or request a key at https://account.ipums.org/api_keys"
+          ),
+          "i" = "Use `set_ipums_api_key()` to save your key for future use."
+        )
       }
-
-      # Otherwise we should be dealing with a valid registration but invalid key
-      error_details <- c(
-        "x" = "The provided API key is either missing or invalid.",
-        "i" = paste0(
-          "Please provide your API key to the `api_key` argument ",
-          "or request a key at https://account.ipums.org/api_keys"
-        ),
-        "i" = "Use `set_ipums_api_key()` to save your key for future use."
-      )
     }
 
     # If a downloads request, add hint to inform of possible issue
@@ -1327,12 +1329,12 @@ spec_add <- function(extract_spec, spec) {
 
 # Helper to drive the logic comparing two spec objects and removing
 # the detailed specification values present in both from the first spec object.
-spec_setdiff <- function(spec, spec_mod, validate = FALSE) {
+spec_setdiff <- function(spec, spec_mod) {
   UseMethod("spec_setdiff")
 }
 
 #' @export
-spec_setdiff.ipums_spec <- function(spec, spec_mod, validate = FALSE) {
+spec_setdiff.ipums_spec <- function(spec, spec_mod) {
   if (spec$name != spec_mod$name) {
     return(spec)
   }
@@ -1350,15 +1352,11 @@ spec_setdiff.ipums_spec <- function(spec, spec_mod, validate = FALSE) {
     }
   )
 
-  if (validate) {
-    spec <- validate_ipums_extract(spec)
-  }
-
   spec
 }
 
 #' @export
-spec_setdiff.var_spec <- function(spec, spec_mod, validate = FALSE) {
+spec_setdiff.var_spec <- function(spec, spec_mod) {
   if (spec$name != spec_mod$name) {
     return(spec)
   }
@@ -1387,21 +1385,17 @@ spec_setdiff.var_spec <- function(spec, spec_mod, validate = FALSE) {
     spec$case_selection_type <- NULL
   }
 
-  if (validate) {
-    spec <- validate_ipums_extract(spec)
-  }
-
   spec
 }
 
 # Helper to drive the logic comparing two spec objects and unioning
 # the detailed specification values present in the second with the first.
-spec_union <- function(spec, spec_mod, validate = FALSE) {
+spec_union <- function(spec, spec_mod) {
   UseMethod("spec_union")
 }
 
 #' @export
-spec_union.ipums_spec <- function(spec, spec_mod, validate = FALSE) {
+spec_union.ipums_spec <- function(spec, spec_mod) {
   if (spec$name != spec_mod$name) {
     return(spec)
   }
@@ -1415,15 +1409,11 @@ spec_union.ipums_spec <- function(spec, spec_mod, validate = FALSE) {
     }
   )
 
-  if (validate) {
-    spec <- validate_ipums_extract(spec)
-  }
-
   spec
 }
 
 #' @export
-spec_union.var_spec <- function(spec, spec_mod, validate = FALSE) {
+spec_union.var_spec <- function(spec, spec_mod) {
   if (spec$name != spec_mod$name) {
     return(spec)
   }
@@ -1447,15 +1437,11 @@ spec_union.var_spec <- function(spec, spec_mod, validate = FALSE) {
     }
   )
 
-  if (validate) {
-    spec <- validate_ipums_extract(spec)
-  }
-
   spec
 }
 
 #' @export
-spec_union.tu_var_spec <- function(spec, spec_mod, validate = FALSE) {
+spec_union.tu_var_spec <- function(spec, spec_mod) {
   if (spec$name != spec_mod$name) {
     return(spec)
   }
@@ -1475,10 +1461,6 @@ spec_union.tu_var_spec <- function(spec, spec_mod, validate = FALSE) {
     }
   )
 
-  if (validate) {
-    spec <- validate_ipums_extract(spec)
-  }
-
   spec
 }
 
@@ -1493,17 +1475,23 @@ copy_ipums_extract <- function(extract) {
   extract
 }
 
-check_api_support <- function(collection) {
+check_api_support <- function(collection, collection_type = NULL) {
   versions <- dplyr::filter(ipums_data_collections(), .data$api_support)
 
+  if (!rlang::is_null(collection_type)) {
+    versions <- versions[versions[["collection_type"]] == collection_type, ]
+    collection_type <- paste0(" ", collection_type) # For better printing
+  }
+
   if (!collection %in% versions$code_for_api) {
     rlang::abort(
       c(
         paste0(
-          "Unrecognized collection: \"", collection, "\""
+          "Unrecognized", collection_type, " collection: \"", collection, "\""
         ),
         "i" = paste0(
-          "The IPUMS API supports collections: \"",
+          "The IPUMS API supports the following",
+          collection_type, " collections: \"",
           paste0(versions$code_for_api, collapse = "\", \""), "\""
         )
       )
