@@ -49,12 +49,10 @@
 #'   adjusted to avoid name conflicts if another column named `"layer"` already
 #'   exists in the data.
 #' @param verbose If `TRUE` report additional progress information on load.
-#' @param shape_layer `r lifecycle::badge("deprecated")` Please use
-#'   `file_select` instead.
 #'
 #' @return An [sf][sf::sf()] object
 #'
-#' @seealso [read_ipums_micro()] or [read_nhgis()] to read tabular data from
+#' @seealso [read_ipums_micro()] or [read_ipums_agg()] to read tabular data from
 #'   an IPUMS extract.
 #'
 #'  [ipums_list_files()] to list files in an IPUMS extract.
@@ -64,7 +62,7 @@
 #' @examplesIf requireNamespace("sf")
 #' # Example shapefile from NHGIS
 #' shape_ex1 <- ipums_example("nhgis0972_shape_small.zip")
-#' data_ex1 <- read_nhgis(ipums_example("nhgis0972_csv.zip"), verbose = FALSE)
+#' data_ex1 <- read_ipums_agg(ipums_example("nhgis0972_csv.zip"), verbose = FALSE)
 #'
 #' sf_data <- read_ipums_sf(shape_ex1)
 #'
@@ -93,22 +91,10 @@ read_ipums_sf <- function(shape_file,
                           encoding = NULL,
                           bind_multiple = FALSE,
                           add_layer_var = NULL,
-                          verbose = FALSE,
-                          shape_layer = deprecated()) {
+                          verbose = FALSE) {
   custom_check_file_exists(shape_file)
 
-  if (!missing(shape_layer)) {
-    lifecycle::deprecate_warn(
-      "0.6.0",
-      "read_ipums_sf(shape_layer = )",
-      "read_ipums_sf(file_select = )",
-    )
-    file_select <- enquo(shape_layer)
-  } else {
-    file_select <- enquo(file_select)
-  }
-
-  dir_read_deprecated(shape_file)
+  file_select <- enquo(file_select)
 
   vars <- enquo(vars)
   load_sf_namespace()
