@@ -32,33 +32,21 @@ select_var_rows <- function(df, vars, filter_var = "var_name") {
   df
 }
 
-
 find_files_in <- function(file,
                           name_ext = NULL,
                           file_select = quo(NULL),
+                          pattern_exclude = NULL,
                           multiple_ok = FALSE,
                           none_ok = TRUE) {
   stopifnot(length(file) == 1)
+  file_names <- character(0)
 
   if (file_is_zip(file)) {
     file_names <- sort(utils::unzip(file, list = TRUE)$Name)
   } else if (file_is_dir(file)) {
     file_names <- sort(dir(file))
   } else {
-    if (!grepl(name_ext, file)) {
-      if (none_ok) {
-        file <- character(0)
-      } else {
-        rlang::abort(
-          paste0(
-            "Expected `file` to match extension \"", name_ext,
-            "\", but got \"", tools::file_ext(file), "\"."
-          )
-        )
-      }
-    }
-
-    return(file)
+    file_names <- file
   }
 
   if (!is.null(name_ext)) {
@@ -74,6 +62,22 @@ find_files_in <- function(file,
     )
   }
 
+  if (!is.null(pattern_exclude)) {
+    file_names <- fostr_subset(file_names, pattern_exclude, negate = TRUE)
+  }
+
+  if (!none_ok && length(file_names) == 0) {
+    rlang::abort(
+      c(
+        "Unexpected data file.",
+        "i" = paste0(
+          "This may occur if you have changed your extract ",
+          "files from their original names."
+        )
+      )
+    )
+  }
+
   if (!quo_is_null(file_select)) {
     names(file_names) <- file_names
 
@@ -442,13 +446,23 @@ custom_cat <- function(..., indent = 0, exdent = 0) {
   cat(custom_format_text(..., indent = indent, exdent = exdent))
 }
 
-custom_check_file_exists <- function(file, extra_ext = NULL) {
+custom_check_file_exists <- function(file,
+                                     extra_ext = NULL,
+                                     allow_dir = FALSE) {
   if (length(file) == 0) {
     rlang::abort("Expected a file path but got an empty value.")
   }
   if (length(file) != 1 && !is.null(extra_ext)) {
     rlang::abort("Bad file path argument.")
   }
+  if (file_is_dir(file) && !allow_dir) {
+    rlang::abort(
+      paste0(
+        "Expected file `", file,
+        "` to be a file path, but got a directory."
+      )
+    )
+  }
 
   # If a path is passed with a trailing "/", file.exists returns FALSE, so
   # this is a way to remove that trailing /
@@ -713,16 +727,3 @@ empty_to_null <- function(x) {
     x
   }
 }
-
-dir_read_deprecated <- function(file) {
-  if (is.character(file) && file_is_dir(file)) {
-    lifecycle::deprecate_warn(
-      "0.6.3",
-      I("Reading files through a directory "),
-      details = "Please provide the full path to file to be loaded.",
-      id = "dir_read",
-      env = caller_env(),
-      user_env = caller_env(2)
-    )
-  }
-}
